library(shiny)

shinyServer(function(input, output) {

    red <- paste("<font color=\"red\">")             
    black <- paste("<font color=\"black\">")             

    digits <- reactive({
        if(input$which=="Type I") digits<-3
        if(input$which=="Type II") digits<-4
        if(input$which=="Type III") digits<-5
        if(input$which=="Type IIII") digits<-2
        digits
    })    

    data <- reactive({ 
         if(input$which=="Type I") x <- round(rnorm(input$n,10,3),1)
         if(input$which=="Type II") x <- round(rnorm(input$n,30,5),2)
         if(input$which=="Type III") x <- round(rnorm(input$n,0.5,0.1),3)
         if(input$which=="Type IIII") x <- round(rnorm(input$n,200,50))
         x
    })              
 
   output$text <- renderText({
        x <- data()
        if(input$ord=="Yes") x <- sort(x)
        if(input$whichp=="First Quartile") p <- 25
        if(input$whichp=="Third Quartile") p <- 75
        if(input$whichp=="Other") p <- input$p
        loc <- ceiling(input$n*p/100)

        if(input$sol=="No") {
            x1 <- paste(x,"&nbsp;",collapse="  ")
            return(c(paste("<h4>",x1,"</h4>"),"<hr>"))
        }      
        else {
            cols <- c(rep(black,loc-1),red,rep(black,input$n-loc))
            x1 <- paste(cols,sort(x),"&nbsp;",collapse="  ")
            line <- c(paste("<h4>",x1,"</h4>"),"<hr>")
        }
        if(input$whichp=="First Quartile") line[3] <- "<h4>We want to find Q<sub>1</sub> = P<sub>25</sub></h4>"
        if(input$whichp=="Third Quartile") line[3] <- "<h4>We want to find Q<sub>3</sub> = P<sub>75</sub></h4>"
        if(input$whichp=="Other") line[3] <- paste("<h4>We want to find P<sub>",p,"</sub></h4>",sep="")
        
        
        line[4] <- paste("<h4>n*p/100 = ",input$n,"*",p,"/100 = ",input$n*p/100,
                   ", round <b>up</b> = ",loc,"</h4>")      
        line[5] <- paste("<h4>",loc,"<sup>th</sup> observation in <b>ordered</b> dataset: ",sort(x)[loc],"</h4>")
        line[6] <- paste("<h4>P<sub>",p,"</sub> = ",sort(x)[loc],"</h4>")           
        line 
   })        
   
  output$explainText <- renderText({ 
        "<h5>Explanation: This demo shows how to find percentiles of a dataset </h5>"
        
  })
  
   output$appinfo <- renderText({ 
      HTML("<br>&nbsp;<br>&nbsp;<br>&nbsp;<br>
      <a target=\"_blank\" href=\"http://academic.uprm.edu/wrolke/myapps1.htm#percentile\"><h4>What to do</h4></a><br>
      <h6>Written by: Dr. Wolfgang Rolke<br>Created: 2/9/2015</h6>")
      
  })       
  

})

